Skip to contents

Returns the most recent EFO that had been published on or before date. Useful for reproducing analyses as they would have looked at a given point in time, before subsequent forecast revisions.

Usage

obr_as_of(date, publication = "EFO")

Arguments

date

A Date, or anything coercible to one (e.g. "2024-11-15").

publication

Currently only "EFO" is supported.

Value

A length-one character vector containing the vintage label, e.g. "October 2024".

Examples

obr_as_of("2024-11-15")
#> [1] "October 2024"
obr_as_of(Sys.Date())
#> [1] "March 2026"