Downloads (and caches) the OBR Welfare Trends Report charts and tables workbook and returns annual spending on each incapacity benefit as a share of GDP, from 1978-79 to the current forecast horizon.
Value
An obr_tbl with the standard v0.4.0 schema. series is the
benefit name, values are spending as a percentage of GDP, metric_type
is "pct", unit is "pct". See get_public_finances() for full
column docs.
Details
Series include: Invalidity Benefit, Incapacity Benefit, Employment and Support Allowance (ESA), Sickness Benefit, and Severe Disablement Allowance.
See also
Other welfare:
get_incapacity_caseloads(),
get_welfare_spending()
Examples
# \donttest{
op <- options(obr.cache_dir = tempdir())
ib <- get_incapacity_spending()
#> ℹ Loading from cache. Use `refresh = TRUE` to re-download.
unique(ib$series)
#> [1] "Employment and support allowance (excluding assessment phase)"
#> [2] "Incapacity benefit"
#> [3] "Invalidity benefit"
#> [4] "Sickness benefit"
#> [5] "Severe disablement allowance"
#> [6] "Universal credit health (excluding assessment phase)"
#> [7] "Income support (incapacity/sick and disabled)"
#> [8] "Incapacity benefits (total)"
options(op)
# }