Returns the most recent EFO that had been published on or before date.
Useful for reproducing analyses as they would have looked at a given point
in time, before subsequent forecast revisions.
See also
Other vintage:
obr_efo_vintages(),
obr_pin(),
obr_pinned(),
obr_unpin()
Examples
obr_as_of("2024-11-15")
#> [1] "October 2024"
obr_as_of(Sys.Date())
#> [1] "March 2026"